==> ejudge-2.1.37.tgz: ejudge/userlist_clnt/logout.c <==
/* -*- mode: c -*- */
/* $Id: logout.c,v 1.4 2004/06/19 21:58:58 cher Exp $ */

/* Copyright (C) 2002-2004 Alexander Chernov <cher@ispras.ru> */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include "userlist_clnt/private.h"

int
userlist_clnt_logout(struct userlist_clnt *clnt,
                     unsigned long origin_ip,
                     unsigned long long cookie)
{
  struct userlist_pk_do_logout out;
  struct userlist_packet *in = 0;
  void *void_in = 0;
  size_t in_size = 0;
  int r;

  memset(&out, 0, sizeof(out));
  out.request_id = ULS_DO_LOGOUT;
  out.origin_ip = origin_ip;
  out.cookie = cookie;
  if ((r = userlist_clnt_send_packet(clnt, sizeof(out), &out)) < 0) return r;
  if ((r = userlist_clnt_recv_packet(clnt, &in_size, &void_in)) < 0)
    return r;
  in = void_in;
  if (in_size != sizeof(*in) || in->id > 0) {
    xfree(in);
    return -ULS_ERR_PROTOCOL;
  }
  r = in->id;
  xfree(in);
  return r;
}

/**
 * Local variables:
 *  compile-command: "make -C .."
 *  c-font-lock-extra-types: ("\\sw+_t" "FILE")
 * End:
 */

==> ejudge-2.1.41.tgz: ejudge/userlist_clnt/logout.c <==
/* -*- mode: c -*- */
/* $Id: logout.c,v 1.5 2005/06/23 19:41:43 cher Exp $ */

/* Copyright (C) 2002-2005 Alexander Chernov <cher@ispras.ru> */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include "userlist_clnt/private.h"

int
userlist_clnt_logout(struct userlist_clnt *clnt,
                     int cmd,
                     unsigned long origin_ip,
                     unsigned long long cookie)
{
  struct userlist_pk_do_logout out;
  struct userlist_packet *in = 0;
  void *void_in = 0;
  size_t in_size = 0;
  int r;

  memset(&out, 0, sizeof(out));
  out.request_id = cmd;
  out.origin_ip = origin_ip;
  out.cookie = cookie;
  if ((r = userlist_clnt_send_packet(clnt, sizeof(out), &out)) < 0) return r;
  if ((r = userlist_clnt_recv_packet(clnt, &in_size, &void_in)) < 0)
    return r;
  in = void_in;
  if (in_size != sizeof(*in) || in->id > 0) {
    xfree(in);
    return -ULS_ERR_PROTOCOL;
  }
  r = in->id;
  xfree(in);
  return r;
}

/**
 * Local variables:
 *  compile-command: "make -C .."
 *  c-font-lock-extra-types: ("\\sw+_t" "FILE")
 * End:
 */
